# OpenBroker

**OpenBroker** is a Python library built by AlgoTest to provide a simple scriptable interface
to the OMS at AlgoTest platform, enabling every user to code their own trading strategy and manage orders easily in a broker-agnostic manner.

## Installation

Installing the library is as simple as running the following command:

```bash
pip install openbroker
```

## Usage

The library is designed to be as simple as possible to use. Take a look at the [examples](https://github.com/Algo-Test/openbroker/tree/main/examples).

## Documentation

The documentation for the library can be found [here](https://algo-test.github.io/openbroker/).

## Contributing

Contributions are welcome! Please read [CONTRIBUTING.md](https://github.com/Algo-Test/openbroker/blob/main/CONTRIBUTING.md) for more information.

## License

This project is licensed under the terms of the [MIT License](https://github.com/Algo-Test/openbroker/blob/main/LICENSE).

## Disclaimer

This project is not affiliated with AlgoTest in any way.
